package com.bonus.material.basic.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.basic.mapper.BmQrcodeInfoMapper;
import com.bonus.material.basic.domain.BmQrcodeInfo;
import com.bonus.material.basic.service.IBmQrcodeInfoService;

/**
 * 二维码管理Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-26
 */
@Service
public class BmQrcodeInfoServiceImpl implements IBmQrcodeInfoService 
{
    @Autowired
    private BmQrcodeInfoMapper bmQrcodeInfoMapper;

    /**
     * 查询二维码管理
     * 
     * @param qrId 二维码管理主键
     * @return 二维码管理
     */
    @Override
    public BmQrcodeInfo selectBmQrcodeInfoByQrId(Long qrId)
    {
        return bmQrcodeInfoMapper.selectBmQrcodeInfoByQrId(qrId);
    }

    /**
     * 查询二维码管理列表
     * 
     * @param bmQrcodeInfo 二维码管理
     * @return 二维码管理
     */
    @Override
    public List<BmQrcodeInfo> selectBmQrcodeInfoList(BmQrcodeInfo bmQrcodeInfo)
    {
        return bmQrcodeInfoMapper.selectBmQrcodeInfoList(bmQrcodeInfo);
    }

    /**
     * 新增二维码管理
     * 
     * @param bmQrcodeInfo 二维码管理
     * @return 结果
     */
    @Override
    public int insertBmQrcodeInfo(BmQrcodeInfo bmQrcodeInfo)
    {
        bmQrcodeInfo.setCreateTime(DateUtils.getNowDate());
        return bmQrcodeInfoMapper.insertBmQrcodeInfo(bmQrcodeInfo);
    }

    /**
     * 修改二维码管理
     * 
     * @param bmQrcodeInfo 二维码管理
     * @return 结果
     */
    @Override
    public int updateBmQrcodeInfo(BmQrcodeInfo bmQrcodeInfo)
    {
        bmQrcodeInfo.setUpdateTime(DateUtils.getNowDate());
        return bmQrcodeInfoMapper.updateBmQrcodeInfo(bmQrcodeInfo);
    }

    /**
     * 批量删除二维码管理
     * 
     * @param qrIds 需要删除的二维码管理主键
     * @return 结果
     */
    @Override
    public int deleteBmQrcodeInfoByQrIds(Long[] qrIds)
    {
        return bmQrcodeInfoMapper.deleteBmQrcodeInfoByQrIds(qrIds);
    }

    /**
     * 删除二维码管理信息
     * 
     * @param qrId 二维码管理主键
     * @return 结果
     */
    @Override
    public int deleteBmQrcodeInfoByQrId(Long qrId)
    {
        return bmQrcodeInfoMapper.deleteBmQrcodeInfoByQrId(qrId);
    }
}
