package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.basic.domain.BmQrcodeInfo;
import com.bonus.material.basic.service.IBmQrcodeInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 二维码管理Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "二维码管理接口")
@RestController
@RequestMapping("/bm_qrcode_info")
public class BmQrcodeInfoController extends BaseController
{
    @Autowired
    private IBmQrcodeInfoService bmQrcodeInfoService;

    /**
     * 查询二维码管理列表
     */
    @ApiOperation(value = "查询二维码管理列表")
    @RequiresPermissions("basic:info:list")
    @GetMapping("/list")
    public TableDataInfo list(BmQrcodeInfo bmQrcodeInfo)
    {
        startPage();
        List<BmQrcodeInfo> list = bmQrcodeInfoService.selectBmQrcodeInfoList(bmQrcodeInfo);
        return getDataTable(list);
    }

    /**
     * 导出二维码管理列表
     */
    @ApiOperation(value = "导出二维码管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:export")
    @SysLog(title = "二维码管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出二维码管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmQrcodeInfo bmQrcodeInfo)
    {
        List<BmQrcodeInfo> list = bmQrcodeInfoService.selectBmQrcodeInfoList(bmQrcodeInfo);
        ExcelUtil<BmQrcodeInfo> util = new ExcelUtil<BmQrcodeInfo>(BmQrcodeInfo.class);
        util.exportExcel(response, list, "二维码管理数据");
    }

    /**
     * 获取二维码管理详细信息
     */
    @ApiOperation(value = "获取二维码管理详细信息")
    @RequiresPermissions("basic:info:query")
    @GetMapping(value = "/{qrId}")
    public AjaxResult getInfo(@PathVariable("qrId") Long qrId)
    {
        return success(bmQrcodeInfoService.selectBmQrcodeInfoByQrId(qrId));
    }

    /**
     * 新增二维码管理
     */
    @ApiOperation(value = "新增二维码管理")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:add")
    @SysLog(title = "二维码管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增二维码管理")
    @PostMapping
    public AjaxResult add(@RequestBody BmQrcodeInfo bmQrcodeInfo)
    {
        return toAjax(bmQrcodeInfoService.insertBmQrcodeInfo(bmQrcodeInfo));
    }

    /**
     * 修改二维码管理
     */
    @ApiOperation(value = "修改二维码管理")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:edit")
    @SysLog(title = "二维码管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改二维码管理")
    @PutMapping
    public AjaxResult edit(@RequestBody BmQrcodeInfo bmQrcodeInfo)
    {
        return toAjax(bmQrcodeInfoService.updateBmQrcodeInfo(bmQrcodeInfo));
    }

    /**
     * 删除二维码管理
     */
    @ApiOperation(value = "删除二维码管理")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:remove")
    @SysLog(title = "二维码管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除二维码管理")
	@DeleteMapping("/{qrIds}")
    public AjaxResult remove(@PathVariable Long[] qrIds)
    {
        return toAjax(bmQrcodeInfoService.deleteBmQrcodeInfoByQrIds(qrIds));
    }
}
